@@ -70,6 +70,7 @@ if(interactive()){
 
 data(PimaIndiansDiabetes, package = "mlbench", envir = environment())
 # We sub-sample to decrease computation time
+suppressWarnings(RNGversion("3.1.0"))
 set.seed(58594084)
 PimaIndiansDiabetes_full <- PimaIndiansDiabetes
 PimaIndiansDiabetes <- PimaIndiansDiabetes[
@@ -82,6 +83,7 @@ BostonHousing <- BostonHousing[
   sample.int(nrow(BostonHousing), 200, replace = FALSE), ]
 
 library("survival")
+data(lung, package = "survival", envir = environment())
 Lung <- lung
 Lung$sex <- factor(Lung$sex)
-Lung <- Lung[complete.cases(Lung), ]
\ No newline at end of file
+Lung <- Lung[complete.cases(Lung), ]
